@@ -1,4 +1,5 @@
 import sys, os
+import json
 from netlib import tcp, http
 import netlib.utils
 import language, utils
@@ -6,13 +7,52 @@ import language, utils
 class PathocError(Exception): pass
 
 
+class Response:
+    def __init__(self, httpversion, status_code, msg, headers, content):
+        self.httpversion, self.status_code, self.msg = httpversion, status_code, msg
+        self.headers, self.content = headers, content
+
+    def __repr__(self):
+        return "Response(%s - %s)"%(self.status_code, self.msg)
+
+
 class Pathoc(tcp.TCPClient):
-    def __init__(self, host, port):
+    def __init__(self, host, port, ssl=None, sni=None, clientcert=None):
         tcp.TCPClient.__init__(self, host, port)
         self.settings = dict(
             staticdir = os.getcwd(),
             unconstrained_file_access = True,
         )
+        self.ssl, self.sni = ssl, sni
+        self.clientcert = clientcert
+
+    def http_connect(self, connect_to, wfile, rfile):
+        wfile.write(
+                    'CONNECT %s:%s HTTP/1.1\r\n'%tuple(connect_to) +
+                    '\r\n'
+                    )
+        wfile.flush()
+        l = rfile.readline()
+        if not l:
+            raise PathocError("Proxy CONNECT failed")
+        parsed = http.parse_response_line(l)
+        if not parsed[1] == 200:
+            raise PathocError("Proxy CONNECT failed: %s - %s"%(parsed[1], parsed[2]))
+        headers = http.read_headers(rfile)
+
+    def connect(self, connect_to=None):
+        """
+            connect_to: A (host, port) tuple, which will be connected to with an
+            HTTP CONNECT request.
+        """
+        tcp.TCPClient.connect(self)
+        if connect_to:
+            self.http_connect(connect_to, self.wfile, self.rfile)
+        if self.ssl:
+            try:
+                self.convert_to_ssl(sni=self.sni, cert=self.clientcert)
+            except tcp.NetLibError, v:
+                raise PathocError(str(v))
 
     def request(self, spec):
         """
@@ -24,7 +64,7 @@ class Pathoc(tcp.TCPClient):
         r = language.parse_request(self.settings, spec)
         ret = language.serve(r, self.wfile, self.settings, self.host)
         self.wfile.flush()
-        return http.read_response(self.rfile, r.method, None)
+        return Response(*http.read_response(self.rfile, r.method, None))
 
     def _show_summary(self, fp, httpversion, code, msg, headers, content):
         print >> fp, "<< %s %s: %s bytes"%(code, utils.xrepr(msg), len(content))
