@@ -7,10 +7,10 @@ class TestPathod:
     def test_instantiation(self):
         p = pathod.Pathod(
                 ("127.0.0.1", 0),
-                anchors = [(".*", "200")]
+                anchors = [(".*", "200:da")]
             )
         assert p.anchors
-        tutils.raises("invalid regex", pathod.Pathod, ("127.0.0.1", 0), anchors=[("*", "200")])
+        tutils.raises("invalid regex", pathod.Pathod, ("127.0.0.1", 0), anchors=[("*", "200:da")])
         tutils.raises("invalid page spec", pathod.Pathod, ("127.0.0.1", 0), anchors=[("foo", "bar")])
 
     def test_logging(self):
@@ -30,16 +30,16 @@ class TestPathod:
 class TestNoWeb(tutils.DaemonTests):
     noweb = True
     def test_noweb(self):
-        assert self.get("200").status_code == 200
+        assert self.get("200:da").status_code == 200
         assert self.getpath("/").status_code == 800
 
 
 class TestTimeout(tutils.DaemonTests):
-    timeout = 0.001
+    timeout = 0.00001
     def test_noweb(self):
         # FIXME: Add float values to spec language, reduce test timeout to
         # increase test performance
-        assert self.get("200:p1,1").status_code == 200
+        tutils.raises("server disconnect", self.pathoc, "get:/:p1,1")
         assert self.d.last_log()["type"] == "timeout"
 
 
@@ -52,6 +52,14 @@ class TestNoApi(tutils.DaemonTests):
         assert not "Log" in r.content
 
 
+class TestNotAfterConnect(tutils.DaemonTests):
+    ssl = False
+    not_after_connect = True
+    def test_connect(self):
+        r = self.pathoc(r"get:'http://foo.com/p/202':da", connect_to=("localhost", self.d.port))
+        assert r.status_code == 202
+
+
 class TestNohang(tutils.DaemonTests):
     nohang = True
     def test_nohang(self):
@@ -80,16 +88,16 @@ class CommonTests(tutils.DaemonTests):
         assert "too large" in l["msg"]
 
     def test_preline(self):
-        v = self.pathoc(r"get:'/p/200':i0,'\r\n'")
-        assert v[1] == 200
+        r = self.pathoc(r"get:'/p/200':i0,'\r\n'")
+        assert r.status_code == 200
 
     def test_info(self):
         assert tuple(self.d.info()["version"]) == version.IVERSION
 
     def test_logs(self):
         assert self.d.clear_log()
-        tutils.raises("no requests logged", self.d.last_log)
-        rsp = self.get("202")
+        assert not self.d.last_log()
+        rsp = self.get("202:da")
         assert len(self.d.log()) == 1
         assert self.d.clear_log()
         assert len(self.d.log()) == 0
@@ -143,9 +151,19 @@ class CommonTests(tutils.DaemonTests):
         assert rsp.status_code == 800
         assert "File access denied" in rsp.content
 
+    def test_proxy(self):
+        r = self.pathoc(r"get:'http://foo.com/p/202':da")
+        assert r.status_code == 202
+
 
 class TestDaemon(CommonTests):
     ssl = False
+    def test_connect(self):
+        r = self.pathoc(r"get:'http://foo.com/p/202':da", connect_to=("localhost", self.d.port), ssl=True)
+        assert r.status_code == 202
+
+    def test_connect_err(self):
+        tutils.raises(http.HttpError, self.pathoc, r"get:'http://foo.com/p/202':da", connect_to=("localhost", self.d.port))
 
 
 class TestDaemonSSL(CommonTests):
